==> 7_years_later_caricature-1.0.0.zip: assets/7_years_later_caricature/animation/maid/default/saki_sit_stair/default.js <==
var GlWrapper = Java.type("com.github.tartaricacid.touhoulittlemaid.client.animation.script.GlWrapper");

Java.asJSONCompatible({
    animation: function(maid, limbSwing, limbSwingAmount, ageInTicks, netHeadYaw, headPitch, scale, modelMap) {
        head = modelMap.get("head");
        legLeft = modelMap.get("legLeft");
        legRight = modelMap.get("legRight");
        armLeft = modelMap.get("armLeft");
        armRight = modelMap.get("armRight");
        ShinLeft = modelMap.get("ShinLeft");
        ShinRight = modelMap.get("ShinRight");

        // 头部复位
        if (head != undefined) {
            head.setOffsetY(head.getInitRotateAngleY());
        }

        if (maid.isRidingMarisaBroom()) {
            // 坐在扫帚上时，应用待命的动作
            ridingBroomPosture(head, armLeft, armRight, legLeft, legRight);
        } else if (maid.isRiding()) {
            ridingPosture(legLeft, legRight, ShinLeft, ShinRight);
        } else if (maid.isSitting()) {
            sittingPosture(armLeft, armRight, legLeft, legRight, ShinLeft, ShinRight);
        }
    }
})

function ridingPosture(legLeft, legRight) {
    if (legLeft != undefined) {
        legLeft.setRotateAngleX(-1.570);
    }
    if (ShinLeft != undefined) {
        ShinLeft.setRotateAngleX(1.178);
    }
    if (legRight != undefined) {
        legRight.setRotateAngleX(-1.570);
    }
    if (ShinRight != undefined) {
        ShinRight.setRotateAngleX(1.134);
    }
    GlWrapper.translate(0, 0.725, 0);
}

function sittingPosture(armLeft, armRight, legLeft, legRight) {
    if (armLeft != undefined) {
        armLeft.setRotateAngleX(-0.798);
        armLeft.setRotateAngleZ(0.274);
    }
    if (armRight != undefined) {
        armRight.setRotateAngleX(-0.798);
        armRight.setRotateAngleZ(-0.274);
    }
    if (legLeft != undefined) {
        legLeft.setRotateAngleX(-1.570);
    }
    if (legRight != undefined) {
        legRight.setRotateAngleX(-1.570);
    }
    if (ShinLeft != undefined) {
        ShinLeft.setRotateAngleX(ShinLeft.getInitRotateAngleX());
    }
    if (ShinRight != undefined) {
        ShinRight.setRotateAngleX(ShinRight.getInitRotateAngleX());
    }
    GlWrapper.translate(0, 0.85, 0);
}

function ridingBroomPosture(head, armLeft, armRight, legLeft, legRight) {
    sittingPosture(armLeft, armRight, legLeft, legRight);
    if (head != undefined) {
        head.setRotateAngleX(head.getRotateAngleX() - 30 * Math.PI / 180);
        head.setOffsetY(0.0625);
    }
    GlWrapper.rotate(30, 1, 0, 0);
    GlWrapper.translate(0, -0.4, -0.3);
}

==> 7_years_later_caricature-1.1.2.zip: assets/7_years_later_caricature/animation/maid/default/saki_sit_stair/default.js <==
var GlWrapper = Java.type("com.github.tartaricacid.touhoulittlemaid.client.animation.script.GlWrapper");

Java.asJSONCompatible({
    animation: function (maid, limbSwing, limbSwingAmount, ageInTicks, netHeadYaw, headPitch, scale, modelMap) {
        head = modelMap.get("head");
        legLeft = modelMap.get("legLeft");
        legRight = modelMap.get("legRight");
        armLeft = modelMap.get("armLeft");
        armRight = modelMap.get("armRight");
        ShinLeft = modelMap.get("ShinLeft");
        ShinRight = modelMap.get("ShinRight");

        // 头部复位
        if (head != undefined) {
            head.setOffsetY(0);
        }

        if (maid.isRidingMarisaBroom()) {
            // 坐在扫帚上时，应用待命的动作
            ridingBroomPosture(head, armLeft, armRight, legLeft, legRight);
        } else if (maid.isRiding()) {
            ridingPosture(legLeft, legRight, ShinLeft, ShinRight);
        } else if (maid.isSitting()) {
            sittingPosture(armLeft, armRight, legLeft, legRight, ShinLeft, ShinRight);
        }
    }
})

function ridingPosture(legLeft, legRight) {
    if (legLeft != undefined) {
        legLeft.setRotateAngleX(-1.570);
        legLeft.setRotateAngleZ(-0.087);
    }
    if (ShinLeft != undefined) {
        ShinLeft.setRotateAngleX(1.178);
    }
    if (legRight != undefined) {
        legRight.setRotateAngleX(-1.570);
        legRight.setRotateAngleZ(0.043);
    }
    if (ShinRight != undefined) {
        ShinRight.setRotateAngleX(1.221);
    }
    GlWrapper.translate(0, 0.725, 0);
}

function sittingPosture(armLeft, armRight, legLeft, legRight) {
    if (armLeft != undefined) {
        armLeft.setRotateAngleX(-0.798);
        armLeft.setRotateAngleZ(0.274);
    }
    if (armRight != undefined) {
        armRight.setRotateAngleX(-0.798);
        armRight.setRotateAngleZ(-0.274);
    }
    if (legLeft != undefined) {
        legLeft.setRotateAngleX(-1.570);
        legLeft.setRotateAngleZ(-0.087);
    }
    if (legRight != undefined) {
        legRight.setRotateAngleX(-1.570);
        legRight.setRotateAngleZ(0.043);
    }
    if (ShinLeft != undefined) {
        ShinLeft.setRotateAngleX(0);
    }
    if (ShinRight != undefined) {
        ShinRight.setRotateAngleX(0);
    }
    GlWrapper.translate(0, 0.85, 0);
}

function ridingBroomPosture(head, armLeft, armRight, legLeft, legRight) {
    sittingPosture(armLeft, armRight, legLeft, legRight);
    if (head != undefined) {
        head.setRotateAngleX(head.getRotateAngleX() - 30 * Math.PI / 180);
        head.setOffsetY(0.0625);
    }
    GlWrapper.rotate(30, 1, 0, 0);
    GlWrapper.translate(0, -0.4, -0.3);
}
